==> jupyter-notebook_6.2.0.orig.tar.gz: notebook-6.2.0/docs-translations/zh-CN/README.md <==
# Jupyter Notebook

[![Google Group](https://img.shields.io/badge/-Google%20Group-lightgrey.svg)](https://groups.google.com/forum/#!forum/jupyter)
[![Build Status](https://travis-ci.org/jupyter/notebook.svg?branch=master)](https://travis-ci.org/jupyter/notebook)
[![Documentation Status](https://readthedocs.org/projects/jupyter-notebook/badge/?version=latest)](https://jupyter-notebook.readthedocs.io/en/latest/?badge=latest)
                


Jupyter Notebook是用于交互的基于Web的笔记本环境
计算。

![Jupyter notebook example](docs/resources/running_code_med.png "Jupyter notebook example")

### 注意
请注意，这家商店目前由木星社区的骨干团队维护。我们鼓励用户过渡到 JupyterLab，那里可能会立即提供更多支持。我们的方法将向前发展：

1.维护Jupiter笔记本电脑的安全性。这意味着与安全相关的问题和请求是我们的首要任务。
2.解决JupyterLab [促进平等问题](https://github.com/jupyterlab/jupyterlab/issues?q=is%3Aopen+is%3Aissue+label%3A%22tag%3AFeature+Parity%22)|作为这项工作的一部分，我们有更好的[仅限笔记本电脑的体验](https://github.com/jupyterlab/jupyterlab/issues/8450)在JupyterLab中，适合喜欢经典Jupyter笔记本UI的用户。
3.负责提出请求请求的社区成员的辛勤工作。我们正在尝试这些PR。我们目前无法支持或维护新设施，但是我们欢迎安全性和其他稳定性方面的改进。

如果您有一个具有新功能的打开请求请求，或者您打算打开一个请求，请将该请求命名为[notebook extension](https://jupyter-notebook.readthedocs.io/en/stable/extending/) 考虑运送为。代替。

##### 选择贡献“笔记本”
此外，请考虑您的贡献是否适合Jupyter前端的基础服务器， [jupyter server](https://github.com/jupyter/jupyter_server) 或在 [JupyterLab 前端](https://github.com/jupyterlab/jupyterlab).

### Jupyter笔记本，与IPython笔记本无关的语言开发
Jupyter Notebook是与语言无关的HTML Notebook应用程序
木星计划。 2015年，木星作为笔记本的一部分发布
IPython代码库的Big Split™。 IPython 3是最后一个主要的整体
两种与语言无关的代码，例如 *IPython notebook*，
以及特定语言的代码，例如 *用于Python的IPython内核* 。如
通过多种语言计算SPAN，Jupyter项目将继续发展
与语言无关 **Jupyter Notebook** 在此仓库中更多帮助下
社区开发自己发现的特定于语言的内核
离散回购。
[[Big Split™ 宣言](https://blog.jupyter.org/the-big-split-9d7b88a031a7)]
[[Jupyter 升序博客文章](https://blog.jupyter.org/jupyter-ascending-1bf5b362d97e)]

## 成立
您可以找到以下安装文件
[Jupiter论坛，在ReadTheDocs上](https://jupyter.readthedocs.io/en/latest/install.html).
可以找到有关Jupiter笔记本的高级使用的文档
[这里](https://jupyter-notebook.readthedocs.io/en/latest/).

对于本地安装，请确保您已经
[pip 成立时间](https://pip.readthedocs.io/en/stable/installing/) 并运行：

    $ pip install notebook

## 用法-运行木星笔记本

### 在本地安装中运行

与启动

    $ jupyter笔记本

### 在远程安装中运行

在远程启动Jupiter笔记本电脑之前，需要进行一些配置。请参阅 [运行笔记本服务器](https://jupyter-notebook.readthedocs.io/en/stable/public_server.html).

## 开发设置

有关如何建立本地发展 [`CONTRIBUTING.rst`](CONTRIBUTING.rst) 看到。

## 贡献

如果您有兴趣为这个项目做贡献，请参阅 [`CONTRIBUTING.rst`](CONTRIBUTING.rst).

## 资源
- [Project Jupyter website](https://jupyter.org)
- [Online Demo at jupyter.org/try](https://jupyter.org/try)
- [Documentation for Jupyter notebook](https://jupyter-notebook.readthedocs.io/en/latest/) [[PDF](https://media.readthedocs.org/pdf/jupyter-notebook/latest/jupyter-notebook.pdf)]
- [Korean Version of Installation](https://github.com/ChungJooHo/Jupyter_Kor_doc/)
- [Documentation for Project Jupyter](https://jupyter.readthedocs.io/en/latest/index.html) [[PDF](https://media.readthedocs.org/pdf/jupyter/latest/jupyter.pdf)]
- [Issues](https://github.com/jupyter/notebook/issues)
- [Technical support - Jupyter Google Group](https://groups.google.com/forum/#!forum/jupyter)

==> jupyter-notebook_6.4.8.orig.tar.gz: notebook-6.4.8/docs-translations/zh-CN/README.md <==
# Jupyter Notebook

[![Google Group](https://img.shields.io/badge/-Google%20Group-lightgrey.svg)](https://groups.google.com/forum/#!forum/jupyter)
[![Build Status](https://travis-ci.org/jupyter/notebook.svg?branch=master)](https://travis-ci.org/jupyter/notebook)
[![Documentation Status](https://readthedocs.org/projects/jupyter-notebook/badge/?version=latest)](https://jupyter-notebook.readthedocs.io/en/latest/?badge=latest)
                


Jupyter Notebook是用于交互的基于Web的笔记本环境
计算。

![Jupyter notebook example](resources/running_code_med.png "Jupyter notebook example")

### 注意
请注意，这家商店目前由木星社区的骨干团队维护。我们鼓励用户过渡到 JupyterLab，那里可能会立即提供更多支持。我们的方法将向前发展：

1.维护Jupiter笔记本电脑的安全性。这意味着与安全相关的问题和请求是我们的首要任务。
2.解决JupyterLab [促进平等问题](https://github.com/jupyterlab/jupyterlab/issues?q=is%3Aopen+is%3Aissue+label%3A%22tag%3AFeature+Parity%22)|作为这项工作的一部分，我们有更好的[仅限笔记本电脑的体验](https://github.com/jupyterlab/jupyterlab/issues/8450)在JupyterLab中，适合喜欢经典Jupyter笔记本UI的用户。
3.负责提出请求请求的社区成员的辛勤工作。我们正在尝试这些PR。我们目前无法支持或维护新设施，但是我们欢迎安全性和其他稳定性方面的改进。

如果您有一个具有新功能的打开请求请求，或者您打算打开一个请求，请将该请求命名为[notebook extension](https://jupyter-notebook.readthedocs.io/en/stable/extending/) 考虑运送为。代替。

##### 选择贡献“笔记本”
此外，请考虑您的贡献是否适合Jupyter前端的基础服务器， [jupyter server](https://github.com/jupyter/jupyter_server) 或在 [JupyterLab 前端](https://github.com/jupyterlab/jupyterlab).

### Jupyter笔记本，与IPython笔记本无关的语言开发
Jupyter Notebook是与语言无关的HTML Notebook应用程序
木星计划。 2015年，木星作为笔记本的一部分发布
IPython代码库的Big Split™。 IPython 3是最后一个主要的整体
两种与语言无关的代码，例如 *IPython notebook*，
以及特定语言的代码，例如 *用于Python的IPython内核* 。如
通过多种语言计算SPAN，Jupyter项目将继续发展
与语言无关 **Jupyter Notebook** 在此仓库中更多帮助下
社区开发自己发现的特定于语言的内核
离散回购。
[[Big Split™ 宣言](https://blog.jupyter.org/the-big-split-9d7b88a031a7)]
[[Jupyter 升序博客文章](https://blog.jupyter.org/jupyter-ascending-1bf5b362d97e)]

## 成立
您可以找到以下安装文件
[Jupiter论坛，在ReadTheDocs上](https://jupyter.readthedocs.io/en/latest/install.html).
可以找到有关Jupiter笔记本的高级使用的文档
[这里](https://jupyter-notebook.readthedocs.io/en/latest/).

对于本地安装，请确保您已经
[pip 成立时间](https://pip.readthedocs.io/en/stable/installing/) 并运行：

    $ pip install notebook

## 用法-运行木星笔记本

### 在本地安装中运行

与启动

    $ jupyter笔记本

### 在远程安装中运行

在远程启动Jupiter笔记本电脑之前，需要进行一些配置。请参阅 [运行笔记本服务器](https://jupyter-notebook.readthedocs.io/en/stable/public_server.html).

## 开发设置

有关如何建立本地发展 [`CONTRIBUTING.rst`](CONTRIBUTING.rst) 看到。

## 贡献

如果您有兴趣为这个项目做贡献，请参阅 [`CONTRIBUTING.rst`](CONTRIBUTING.rst).

## 资源
- [Project Jupyter website](https://jupyter.org)
- [Online Demo at jupyter.org/try](https://jupyter.org/try)
- [Documentation for Jupyter notebook](https://jupyter-notebook.readthedocs.io/en/latest/) [[PDF](https://media.readthedocs.org/pdf/jupyter-notebook/latest/jupyter-notebook.pdf)]
- [Korean Version of Installation](https://github.com/ChungJooHo/Jupyter_Kor_doc/)
- [Documentation for Project Jupyter](https://jupyter.readthedocs.io/en/latest/index.html) [[PDF](https://media.readthedocs.org/pdf/jupyter/latest/jupyter.pdf)]
- [Issues](https://github.com/jupyter/notebook/issues)
- [Technical support - Jupyter Google Group](https://groups.google.com/forum/#!forum/jupyter)
